import { reactive, onMounted, ref, ElMessage, ElMessageBox, http, getGroupUrl, RegularVerification, verification, PaginationProps } from "@/utils/importUsed"
// 接口列表实例
const UserUrl = ref(null)
// 获取当前板块接口列表
onMounted(async () => {
  UserUrl.value = await getGroupUrl(["User"]);

})
// 表单实例
const ruleFormRef = ref()
export function useUser() {
  // 搜索表单参数（需动态生成请求字段）
  const form = reactive({
    searchMain: "", // 搜索内容
    select: "", // 选择项
    date: "",
  });
  // 级联选择器参数
  const optionList = ref([
    {
      value: "resource",
      label: "Resource",
      children: [
        {
          value: "axure",
          label: "Axure Components"
        },
        {
          value: "sketch",
          label: "Sketch Templates"
        },
        {
          value: "docs",
          label: "Design Documentation"
        }
      ]
    }
  ]);
  // 表格数据列表
  const dataList = ref([]);
  // 页面加载状态
  const loading = ref(false);
  // 表格分页选择器
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 10,
    currentPage: 1,
    background: true
  });
  // 表格数据（根据字段生成）
  const columns: TableColumnList = [
    {
      type: "selection",
      width: 55,
      align: "left",
      hide: ({ checkList }) => !checkList.includes("勾选列")
    },
    {
      label: "序号",
      type: "index",
      width: 70,
      hide: ({ checkList }) => !checkList.includes("序号列")
    },
    {
      label: "角色ID",
      prop: "Id",
      minWidth: 130
    },
    {
      label: "操作",
      fixed: "right",
      width: 200,
      slot: "operation"
    }
  ];
  // 当前页数量切换
  function handleSizeChange(val: number) {
    console.log(`${val} items per page`);
    onSearch(ruleFormRef);
  }
  // 当前页码切换
  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
    onSearch(ruleFormRef);
  }
  // 选择表格项
  function handleSelectionChange(val) {
    console.log("handleSelectionChange", val);
    onSearch(ruleFormRef);
  }
  // 搜索列表
  async function onSearch(formEl) {
    // 表单校验拦截
    if (!formEl) return
    await formEl.validate((valid, fields) => {
      if (valid) {
        //表单校验成功回调
        console.log('submit!')
        // 状态调整为加载中
        loading.value = true;
        // 调用接口（需动态生成接口）
        const { data, other }: any = http.request(
          UserUrl.User.userSearch.method,
          UserUrl.User.userSearch.url,
          {
            ...form,
            page_size: pagination.pageSize,
            page_num: pagination.currentPage
          }
        );
        dataList.value = data;
        pagination.total = other.Count;
        setTimeout(() => {
          loading.value = false;
        }, 500);
      } else {
        //表单校验失败回调
        ElMessage({
          message: "请输入完整信息",
          type: "error"
        });
      }
    })
  }

  // 删除
  function handleDelete(row) {
    ElMessageBox.confirm(
      `是否删除该用户?  用户名称为:${row.AdminName}`,
      "提示",
      {
        confirmButtonText: "删除",
        cancelButtonText: "取消",
        type: "warning"
      }
    ).then(async () => {
      const { status, info }: any = await http.Request({
        url: UserUrl.User.userDelete.method,
        method: UserUrl.User.userDelete.url,
        params: { SysAdminId: row.Id }
      });
      if (status === "1") {
        ElMessage({
          message: "删除成功",
          type: "success"
        });
        onSearch(ruleFormRef);
      } else {
        ElMessageBox.alert(info, "提示", {
          confirmButtonText: "关闭",
          type: "warning"
        });
      }
    });
  }
  // 新增弹窗开启状态
  const addVisible = ref(false);
  function handleAdd() {
    addVisible.value = true;
  }
  // 修改弹窗开启状态
  const editVisible = ref(false);
  // 修改弹窗数据
  const editFormData = ref({});
  function handleUpdate(row) {
    editVisible.value = true;
    // 表格数据赋值
    editFormData.value = row;
  }

  // 表单校验规则
  const rules = reactive({
    searchMain: [
      // 必传(字段名动态生成)
      { required: true, message: '请输入搜索内容', trigger: 'blur' },
    ],
    select: [
      // 必传
      { required: true, message: '请输入选择项', trigger: 'blur' },
      // 长度
      { min: 3, max: 5, message: '长度为3-5', trigger: 'blur' },
      // 时间类型必填
      {
        type: 'date',
        required: true,
        message: '请选择正确时间类型',
        trigger: 'blur',
      },
      // 封装正则
      {
        validator: (rule: any, value: any, callback: any) => {
          verification.verificationName(value, callback)
        }, trigger: 'blur'
      },
      // 自定义正则
      {
        validator: (rule: any, value: any, callback: any) => {
          // 自定义正则替换
          const regular = /^((13[0-9])|(14(0|[5-7]|9))|(15([0-3]|[5-9]))|(16(2|[5-7]))|(17[0-8])|(18[0-9])|(19([0-3]|[5-9])))\d{8}$/;
          RegularVerification(regular, value, callback)
        }, trigger: 'blur'
      },
    ],
  })
  return {
    form,
    loading,
    columns,
    dataList,
    pagination,
    onSearch,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    handleAdd,
    handleUpdate,
    handleDelete,
    addVisible,
    editVisible,
    editFormData,
    optionList,
    ruleFormRef,
    rules
  };
}
